import os
import shutil

import requests
import pytest

from .test_api import TEST_STACK_MODEL
from . import train_cron

TRAIN_CRON_STACK_MODEL = "train_cron_model"


@pytest.fixture
def api_token(auth_header):
    url = "http://rasa-x:5002/api/user"
    response = requests.get(url, headers=auth_header)
    return response.json().get("api_token")


def test_upload_dev_model(auth_header, api_token):
    shutil.copyfile(
        "{}.tar.gz".format(TEST_STACK_MODEL), "{}.tar.gz".format(TRAIN_CRON_STACK_MODEL)
    )
    assert os.path.exists("{}.tar.gz".format(TRAIN_CRON_STACK_MODEL))

    url = "http://rasa-x:5002/api/projects/default/models"
    with open("{}.tar.gz".format(TRAIN_CRON_STACK_MODEL), "rb") as f:
        response = requests.post(url, headers=auth_header, files={"model": f})
    assert response.status_code == 204

    # tag model as production
    tag_url = (
        "http://rasa-x:5002/api/projects/default/models/"
        "{}/tags/production".format(TRAIN_CRON_STACK_MODEL)
    )
    tag_response = requests.put(tag_url, headers=auth_header)
    assert tag_response.status_code == 204

    old_env = os.environ
    os.environ = os.environ.copy()
    os.environ["RASA_API_TOKEN"] = api_token
    os.environ["RASA_X_HOST"] = "http://rasa-x:5002"
    os.environ["TRAIN_CRON_TESTNG"] = True

    try:
        train_cron.main()
    finally:
        os.environ = old_env
